# CADET-Match
CADET Parameter estimation engine

This software is a work in progress. The file formats will break as changes as made.

This software is designed to do parameter estimation for CADET. The required libraries are in the README.txt file
in the CADETMatch directory.

The documentation is also a work in progress.

If you use this software in your research please give credit.
